#
# Copyright 2021 Canonical Ltd.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License version 3 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

"""Craft Providers base package."""

__version__ = "1.6.0"  # noqa: F401

from .base import Base  # noqa: F401
from .errors import ProviderError  # noqa: F401
from .executor import Executor  # noqa: F401
from .provider import Provider  # noqa: f401

__all__ = [
    "Base",
    "Executor",
    "ProviderError",
    "Provider",
]
